Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorChanaka Indrajith <pe.chanaka.ck@gmail.com>2012-05-13 11:09:31 +0400
committerChanaka Indrajith <pe.chanaka.ck@gmail.com>2012-05-13 11:09:31 +0400
commitdd237eb9243dee3d2fcca7a65e338ab9938137c7 (patch)
tree37ec825430ac703ba28e9ad336f65a79d3aefc54 /test
parent40d0ada69bed5856d75d6b67bb3fc0a1e1df943c (diff)
parent74c2148917dc5d325c6656f2a4a5f15cd5f970aa (diff)
Resolve conflicts due to changes in method names of common.lib.php
Diffstat (limited to 'test')
-rw-r--r--test/classes/PMA_Config_test.php26
-rw-r--r--test/classes/PMA_Theme_test.php33
-rw-r--r--test/libraries/common/PMA_GetDropdown_test.php (renamed from test/libraries/common/PMA_generate_html_dropdown_test.php)10
-rw-r--r--test/libraries/common/PMA_contains_nonprintable_ascii_test.php8
-rw-r--r--test/libraries/common/PMA_convert_bit_default_value_test.php6
-rw-r--r--test/libraries/common/PMA_escapeMySqlWildcards_test.php10
-rw-r--r--test/libraries/common/PMA_foreignKeySupported_test.php4
-rw-r--r--test/libraries/common/PMA_getCheckbox_test.php2
-rw-r--r--test/libraries/common/PMA_getDivForSliderEffect_test.php (renamed from test/libraries/common/PMA_generate_slider_effect_test.php)8
-rw-r--r--test/libraries/common/PMA_getRadioFields_test.php (renamed from test/libraries/common/PMA_display_html_radio_test.php)36
-rw-r--r--test/libraries/common/PMA_printableBitValue_test.php6
-rw-r--r--test/libraries/common/PMA_stringOperations_test.php2
-rw-r--r--test/libraries/core/PMA_headerLocation_test_disabled.php4
-rw-r--r--test/theme.php2
14 files changed, 98 insertions, 59 deletions
diff --git a/test/classes/PMA_Config_test.php b/test/classes/PMA_Config_test.php
index 20972d7449..86194e14ca 100644
--- a/test/classes/PMA_Config_test.php
+++ b/test/classes/PMA_Config_test.php
@@ -3,7 +3,6 @@
/**
* Test for PMA_Config class
*
- *
* @package PhpMyAdmin-test
* @group current
*/
@@ -272,8 +271,10 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @covers PMA_Config::get
* @covers PMA_Config::set
+ *
* @return void
*/
public function testGetAndSet()
@@ -308,6 +309,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @depends testCheckPmaAbsoluteUriEmpty
*/
public function testCheckPmaAbsoluteUriNormal()
@@ -323,6 +325,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @depends testCheckPmaAbsoluteUriNormal
*/
public function testCheckPmaAbsoluteUriScheme()
@@ -339,6 +342,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @depends testCheckPmaAbsoluteUriScheme
*/
public function testCheckPmaAbsoluteUriUser()
@@ -398,6 +402,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @depends testDetectHttps
*/
public function testCheckCookiePath()
@@ -408,6 +413,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @depends testCheckSystem
* @depends testCheckWebServer
* @depends testLoadDefaults
@@ -438,6 +444,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testSave().
*/
public function testSave()
@@ -449,6 +456,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testGetFontsizeForm().
*/
public function testGetFontsizeForm()
@@ -460,6 +468,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testRemoveCookie().
*/
public function testRemoveCookie()
@@ -469,7 +478,8 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
'This test has not been implemented yet.'
);
}
- /**
+ /**
+ *
* @todo Implement testCheckFontsize().
*/
public function testCheckFontsize()
@@ -481,6 +491,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testCheckUpload().
*/
public function testCheckUpload()
@@ -492,6 +503,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testCheckUploadSize().
*/
public function testCheckUploadSize()
@@ -503,6 +515,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testCheckIsHttps().
*/
public function testCheckIsHttps()
@@ -514,6 +527,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testGetCookiePath().
*/
public function testGetCookiePath()
@@ -525,6 +539,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo finish implementing test + dependencies
*/
public function testLoad()
@@ -535,6 +550,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testLoadUserPreferences().
*/
public function testLoadUserPreferences()
@@ -545,6 +561,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testSetUserValue().
*/
public function testSetUserValue()
@@ -555,6 +572,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testGetUserValue().
*/
public function testGetUserValue()
@@ -563,6 +581,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testGetThemeUniqueValue().
*/
public function testGetThemeUniqueValue()
@@ -574,6 +593,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testCheckPermissions().
*/
public function testCheckPermissions()
@@ -586,6 +606,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
/**
+ *
* @todo Implement testSetCookie().
*/
public function testSetCookie()
@@ -602,6 +623,7 @@ class PMA_ConfigTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @dataProvider sslUris
*/
public function testSSLUri($original, $expected)
diff --git a/test/classes/PMA_Theme_test.php b/test/classes/PMA_Theme_test.php
index c35480432f..4608515b85 100644
--- a/test/classes/PMA_Theme_test.php
+++ b/test/classes/PMA_Theme_test.php
@@ -5,7 +5,6 @@ require_once 'libraries/Theme.class.php';
/**
* Test class for PMA_Theme.
- * Generated by PHPUnit on 2011-07-18 at 03:19:13.
*/
class PMA_ThemeTest extends PHPUnit_Framework_TestCase
{
@@ -40,7 +39,10 @@ class PMA_ThemeTest extends PHPUnit_Framework_TestCase
public function testCheckImgPathIncorrect()
{
$this->object->setPath('./test/classes/_data/incorrect_theme');
- $this->assertFalse($this->object->loadInfo(), 'Theme name is not properly set');
+ $this->assertFalse(
+ $this->object->loadInfo(),
+ 'Theme name is not properly set'
+ );
}
public function testCheckImgPathFull()
@@ -54,12 +56,16 @@ class PMA_ThemeTest extends PHPUnit_Framework_TestCase
public function testLoadInfo()
{
$this->object->setPath('./themes/original');
+ $infofile = $this->object->getPath().'/info.inc.php';
$this->assertTrue($this->object->loadInfo());
- $this->assertEquals(filemtime($this->object->getPath().'/info.inc.php'), $this->object->mtime_info);
+ $this->assertEquals(
+ filemtime($infofile),
+ $this->object->mtime_info
+ );
$this->object->setPath('./themes/original');
- $this->object->mtime_info = filemtime($this->object->getPath().'/info.inc.php');
+ $this->object->mtime_info = filemtime($infofile);
$this->assertTrue($this->object->loadInfo());
$this->assertEquals('Original', $this->object->getName());
}
@@ -76,6 +82,7 @@ class PMA_ThemeTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @expectedException PHPUnit_Framework_Error
*/
public function testCheckImgPathBad()
@@ -101,6 +108,7 @@ class PMA_ThemeTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @expectedException PHPUnit_Framework_Error
*/
public function testCheckImgPathGlobalsWrongPath()
@@ -115,6 +123,7 @@ class PMA_ThemeTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @covers PMA_Theme::setPath
* @covers PMA_Theme::getPath
*/
@@ -132,11 +141,16 @@ class PMA_ThemeTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @depends testLoadInfo
*/
public function testGetSetCheckVersion()
{
- $this->assertEquals('0.0.0.0', $this->object->getVersion(), 'Version 0.0.0.0 by default');
+ $this->assertEquals(
+ '0.0.0.0',
+ $this->object->getVersion(),
+ 'Version 0.0.0.0 by default'
+ );
$this->object->setVersion("1.2.3.4");
$this->assertEquals('1.2.3.4', $this->object->getVersion());
@@ -146,6 +160,7 @@ class PMA_ThemeTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @covers PMA_Theme::getName
* @covers PMA_Theme::setName
*/
@@ -158,6 +173,7 @@ class PMA_ThemeTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @covers PMA_Theme::getId
* @covers PMA_Theme::setId
*/
@@ -170,12 +186,16 @@ class PMA_ThemeTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @covers PMA_Theme::getImgPath
* @covers PMA_Theme::setImgPath
*/
public function testGetSetImgPath()
{
- $this->assertEmpty($this->object->getImgPath(), 'ImgPath is empty by default');
+ $this->assertEmpty(
+ $this->object->getImgPath(),
+ 'ImgPath is empty by default'
+ );
$this->object->setImgPath('/new/path');
$this->assertEquals('/new/path', $this->object->getImgPath());
@@ -194,6 +214,7 @@ class PMA_ThemeTest extends PHPUnit_Framework_TestCase
}
/**
+ *
* @todo Implement testPrintPreview().
*/
public function testPrintPreview()
diff --git a/test/libraries/common/PMA_generate_html_dropdown_test.php b/test/libraries/common/PMA_GetDropdown_test.php
index ef7a6f3614..ab01d800be 100644
--- a/test/libraries/common/PMA_generate_html_dropdown_test.php
+++ b/test/libraries/common/PMA_GetDropdown_test.php
@@ -1,7 +1,7 @@
<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
- * Test for PMA_generate_html_dropdown_test from common.lib.php
+ * Test for PMA_getDropdown from common.lib.php
*
* @package PhpMyAdmin-test
* @group common.lib-tests
@@ -12,9 +12,9 @@
*/
require_once 'libraries/common.lib.php';
-class PMA_generate_html_dropdown_test extends PHPUnit_Framework_TestCase
+class PMA_GetDropdownTest extends PHPUnit_Framework_TestCase
{
- function testGenerateHtmlDropdownEmpty()
+ function testGetDropdownEmpty()
{
$name = "test_dropdown_name";
$choices = array();
@@ -26,7 +26,7 @@ class PMA_generate_html_dropdown_test extends PHPUnit_Framework_TestCase
$this->assertEquals($result, PMA_getDropdown($name, $choices, $active_choice, $id));
}
- function testGenerateHtmlDropdown()
+ function testGetDropdown()
{
$name = "&test_dropdown_name";
$choices = array("value_1" => "label_1", "value&_2\"" => "label_2");
@@ -46,7 +46,7 @@ class PMA_generate_html_dropdown_test extends PHPUnit_Framework_TestCase
$this->assertEquals($result, PMA_getDropdown($name, $choices, $active_choice, $id));
}
- function testGenerateHtmlDropdownWithActive()
+ function testGetDropdownWithActive()
{
$name = "&test_dropdown_name";
$choices = array("value_1" => "label_1", "value&_2\"" => "label_2");
diff --git a/test/libraries/common/PMA_escapeMySqlWildcards_test.php b/test/libraries/common/PMA_escapeMySqlWildcards_test.php
index bd2a2efe35..75da9cdd10 100644
--- a/test/libraries/common/PMA_escapeMySqlWildcards_test.php
+++ b/test/libraries/common/PMA_escapeMySqlWildcards_test.php
@@ -12,7 +12,7 @@
*/
require_once 'libraries/common.lib.php';
-class PMA_escapeMySqlWildcards_test extends PHPUnit_Framework_TestCase
+class PMA_EscapeMySqlWildcardsTest extends PHPUnit_Framework_TestCase
{
public function escapeDataProvider()
@@ -30,23 +30,23 @@ class PMA_escapeMySqlWildcards_test extends PHPUnit_Framework_TestCase
}
/**
- * PMA_escape_mysql_wildcards tests
+ * PMA_escapeMysqlWildcards tests
* @dataProvider escapeDataProvider
*/
public function testEscape($a, $b)
{
- $this->assertEquals($a, PMA_escape_mysql_wildcards($b));
+ $this->assertEquals($a, PMA_escapeMysqlWildcards($b));
}
/**
- * PMA_unescape_mysql_wildcards tests
+ * PMA_unescapeMysqlWildcards tests
* @dataProvider escapeDataProvider
*/
public function testUnEscape($a, $b)
{
- $this->assertEquals($b, PMA_unescape_mysql_wildcards($a));
+ $this->assertEquals($b, PMA_unescapeMysqlWildcards($a));
}
}
?>
diff --git a/test/libraries/common/PMA_foreignKeySupported_test.php b/test/libraries/common/PMA_foreignKeySupported_test.php
index 21614462f8..07a0309f14 100644
--- a/test/libraries/common/PMA_foreignKeySupported_test.php
+++ b/test/libraries/common/PMA_foreignKeySupported_test.php
@@ -12,7 +12,7 @@
*/
require_once 'libraries/common.lib.php';
-class PMA_foreignKeySupported_test extends PHPUnit_Framework_TestCase
+class PMA_IsForeignKeySupportedTest extends PHPUnit_Framework_TestCase
{
/**
* data provider for foreign key supported test
@@ -34,7 +34,7 @@ class PMA_foreignKeySupported_test extends PHPUnit_Framework_TestCase
*/
public function testForeignkeySupported($a, $e)
{
- $this->assertEquals($e, PMA_foreignkey_supported($a));
+ $this->assertEquals($e, PMA_isForeignKeySupported($a));
}
}
?>
diff --git a/test/libraries/common/PMA_getCheckbox_test.php b/test/libraries/common/PMA_getCheckbox_test.php
index 1b8ded4679..8030b7385b 100644
--- a/test/libraries/common/PMA_getCheckbox_test.php
+++ b/test/libraries/common/PMA_getCheckbox_test.php
@@ -12,7 +12,7 @@
*/
require_once 'libraries/common.lib.php';
-class PMA_display_html_checkbox_test extends PHPUnit_Framework_TestCase
+class PMA_GetCheckboxTest extends PHPUnit_Framework_TestCase
{
function testGetCheckbox()
{
diff --git a/test/libraries/common/PMA_generate_slider_effect_test.php b/test/libraries/common/PMA_getDivForSliderEffect_test.php
index 40d22c2e1e..ce272d530e 100644
--- a/test/libraries/common/PMA_generate_slider_effect_test.php
+++ b/test/libraries/common/PMA_getDivForSliderEffect_test.php
@@ -12,9 +12,9 @@
*/
require_once 'libraries/common.lib.php';
-class PMA_generate_slider_effect_test extends PHPUnit_Framework_TestCase
+class PMA_GetDivForSliderEffectTest extends PHPUnit_Framework_TestCase
{
- function testGenerateSliderEffectTest()
+ function testGetDivForSliderEffectTest()
{
global $cfg;
$cfg['InitialSlidersState'] = 'undefined';
@@ -26,7 +26,7 @@ class PMA_generate_slider_effect_test extends PHPUnit_Framework_TestCase
PMA_getDivForSliderEffect($id, $message);
}
- function testGenerateSliderEffectTestClosed()
+ function testGetDivForSliderEffectTestClosed()
{
global $cfg;
$cfg['InitialSlidersState'] = 'closed';
@@ -38,7 +38,7 @@ class PMA_generate_slider_effect_test extends PHPUnit_Framework_TestCase
PMA_getDivForSliderEffect($id, $message);
}
- function testGenerateSliderEffectTestDisabled()
+ function testGetDivForSliderEffectTestDisabled()
{
global $cfg;
$cfg['InitialSlidersState'] = 'disabled';
diff --git a/test/libraries/common/PMA_printableBitValue_test.php b/test/libraries/common/PMA_printableBitValue_test.php
index 897ce8355f..d799688787 100644
--- a/test/libraries/common/PMA_printableBitValue_test.php
+++ b/test/libraries/common/PMA_printableBitValue_test.php
@@ -1,7 +1,7 @@
<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
- * Test printableBitValue function
+ * Test PMA_printableBitValue function
*
* @package PhpMyAdmin-test
* @group common.lib-tests
@@ -12,7 +12,7 @@
*/
require_once 'libraries/common.lib.php';
-class PMA_printableBitValue_test extends PHPUnit_Framework_TestCase
+class PMA_PrintableBitValueTest extends PHPUnit_Framework_TestCase
{
/**
@@ -35,7 +35,7 @@ class PMA_printableBitValue_test extends PHPUnit_Framework_TestCase
public function testPrintableBitValue($a, $b, $e)
{
- $this->assertEquals($e, PMA_printable_bit_value($a, $b));
+ $this->assertEquals($e, PMA_printableBitValue($a, $b));
}
}
?>
diff --git a/test/libraries/common/PMA_stringOperations_test.php b/test/libraries/common/PMA_stringOperations_test.php
index ef41166357..ecadc80399 100644
--- a/test/libraries/common/PMA_stringOperations_test.php
+++ b/test/libraries/common/PMA_stringOperations_test.php
@@ -107,7 +107,7 @@ class PMA_stringOperations_test extends PHPUnit_Framework_TestCase
public function testReplaceBinaryContents($a, $e)
{
- $this->assertEquals($e, PMA_replace_binary_contents($a));
+ $this->assertEquals($e, PMA_replaceBinaryContents($a));
}
/**
diff --git a/test/libraries/core/PMA_headerLocation_test_disabled.php b/test/libraries/core/PMA_headerLocation_test_disabled.php
index 2f749d6488..240352ff69 100644
--- a/test/libraries/core/PMA_headerLocation_test_disabled.php
+++ b/test/libraries/core/PMA_headerLocation_test_disabled.php
@@ -196,7 +196,6 @@ class PMA_headerLocation_test extends PHPUnit_Framework_TestCase
if ($this->runkitExt && $this->apdExt) {
runkit_constant_redefine('PMA_IS_IIS', true);
- runkit_constant_add('PMA_COMING_FROM_COOKIE_LOGIN', true);
$testUri = 'http://testurl.com/test.php';
$separator = PMA_get_arg_separator();
@@ -205,9 +204,6 @@ class PMA_headerLocation_test extends PHPUnit_Framework_TestCase
PMA_sendHeaderLocation($testUri); // sets $GLOBALS['header']
- // cleaning constant
- runkit_constant_remove('PMA_COMING_FROM_COOKIE_LOGIN');
-
$this->assertEquals($header, $GLOBALS['header']);
} else {
diff --git a/test/theme.php b/test/theme.php
index 360c682688..56e0630779 100644
--- a/test/theme.php
+++ b/test/theme.php
@@ -143,7 +143,7 @@ $tabs['import']['link'] = 'server_import.php';
$tabs['import']['text'] = 'active';
$tabs['import']['class'] = 'active';
-echo PMA_generate_html_tabs($tabs, array());
+echo PMA_generateHtmlTabs($tabs, array());
unset($tabs);
if (@file_exists($pmaThemeImage . 'logo_right.png')) {
diff --git a/test/libraries/common/PMA_contains_nonprintable_ascii_test.php b/test/libraries/common/PMA_contains_nonprintable_ascii_test.php
index 7bd6f259a9..9d9e8dd275 100644
--- a/test/libraries/common/PMA_contains_nonprintable_ascii_test.php
+++ b/test/libraries/common/PMA_contains_nonprintable_ascii_test.php
@@ -1,7 +1,7 @@
<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
* Test for PMA_contains_nonprintable_ascii from common.lib
*
* @package PhpMyAdmin-test
* @group common.lib-tests
@@ -12,7 +12,7 @@
*/
require_once 'libraries/common.lib.php';
-class PMA_contains_nonprintable_ascii extends PHPUnit_Framework_TestCase
+class PMA_ContainsNonPrintableAsciiTest extends PHPUnit_Framework_TestCase
{
function dataProvider()
@@ -31,9 +31,9 @@ class PMA_contains_nonprintable_ascii extends PHPUnit_Framework_TestCase
*/
function testContainsNonPrintableAscii($str, $res)
{
- $this->assertEquals($res, PMA_contains_nonprintable_ascii($str));
+ $this->assertEquals($res, PMA_containsNonPrintableAscii($str));
}
}
-// PMA_contains_nonprintable_ascii
+// PMA_containsNonPrintableAscii
@@ -1,7 +1,7 @@
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
- * Test for PMA_contains_nonprintable_ascii from common.lib
+ * Test for PMA_containsNonPrintableAscii from common.lib
*
* @package PhpMyAdmin-test
diff --git a/test/libraries/common/PMA_convert_bit_default_value_test.php b/test/libraries/common/PMA_convert_bit_default_value_test.php
index 0439b33385..585c585490 100644
--- a/test/libraries/common/PMA_convert_bit_default_value_test.php
+++ b/test/libraries/common/PMA_convert_bit_default_value_test.php
@@ -1,7 +1,7 @@
<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
* Test for PMA_convert_bit_default_value from common.lib
*
* @package PhpMyAdmin-test
* @group common.lib-tests
@@ -12,7 +12,7 @@
*/
require_once 'libraries/common.lib.php';
-class PMA_convert_bit_default_value_test extends PHPUnit_Framework_TestCase
+class PMA_ConvertBitDefaultValueTest extends PHPUnit_Framework_TestCase
{
function dataProvider()
@@ -29,7 +29,7 @@ class PMA_convert_bit_default_value_test extends PHPUnit_Framework_TestCase
*/
function testConvert_bit_default_value_test($bit, $val)
{
- $this->assertEquals($val, PMA_convert_bit_default_value($bit));
+ $this->assertEquals($val, PMA_convertBitDefaultValue($bit));
}
}
@@ -1,7 +1,7 @@
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
- * Test for PMA_convert_bit_default_value from common.lib
+ * Test for PMA_convertBitDefaultValue from common.lib
*
* @package PhpMyAdmin-test
diff --git a/test/libraries/common/PMA_display_html_radio_test.php b/test/libraries/common/PMA_getRadioFields_test.php
index a93b2485ef..441213fff2 100644
--- a/test/libraries/common/PMA_display_html_radio_test.php
+++ b/test/libraries/common/PMA_getRadioFields_test.php
@@ -1,7 +1,7 @@
<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
* Test for PMA_display_html_radio from common.lib.php
*
* @package PhpMyAdmin-test
* @group common.lib-tests
@@ -12,18 +12,18 @@
*/
require_once 'libraries/common.lib.php';
-class PMA_display_html_radio_test extends PHPUnit_Framework_TestCase
+class PMA_GetRadioFieldsTest extends PHPUnit_Framework_TestCase
{
- function testDisplayHtmlRadioEmpty()
+ function testGetRadioFieldsEmpty()
{
$name = "test_display_radio";
$choices = array();
$this->expectOutputString("");
- PMA_display_html_radio($name, $choices);
+ PMA_displayHtmlRadio($name, $choices);
}
- function testDisplayHtmlRadio()
+ function testGetRadioFields()
{
$name = "test_display_radio";
$choices = array('value_1'=>'choice_1', 'value_2'=>'choice_2');
@@ -39,10 +39,10 @@ class PMA_display_html_radio_test extends PHPUnit_Framework_TestCase
}
$this->expectOutputString($out);
- PMA_display_html_radio($name, $choices);
+ PMA_displayHtmlRadio($name, $choices);
}
- function testDisplayHtmlRadioWithChecked()
+ function testGetRadioFieldsWithChecked()
{
$name = "test_display_radio";
$choices = array('value_1'=>'choice_1', 'value_2'=>'choice_2');
@@ -62,10 +62,10 @@ class PMA_display_html_radio_test extends PHPUnit_Framework_TestCase
}
$this->expectOutputString($out);
- PMA_display_html_radio($name, $choices, $checked_choice);
+ PMA_displayHtmlRadio($name, $choices, $checked_choice);
}
- function testDisplayHtmlRadioWithCheckedWithClass()
+ function testGetRadioFieldsWithCheckedWithClass()
{
$name = "test_display_radio";
$choices = array('value_1'=>'choice_1', 'value_2'=>'choice_2');
@@ -88,10 +88,10 @@ class PMA_display_html_radio_test extends PHPUnit_Framework_TestCase
}
$this->expectOutputString($out);
- PMA_display_html_radio($name, $choices, $checked_choice, true, false, $class);
+ PMA_displayHtmlRadio($name, $choices, $checked_choice, true, false, $class);
}
- function testDisplayHtmlRadioWithoutBR()
+ function testGetRadioFieldsWithoutBR()
{
$name = "test_display_radio";
$choices = array('value_1'=>'choice_1', 'value&_&lt;2&gt;'=>'choice_2');
@@ -110,10 +110,10 @@ class PMA_display_html_radio_test extends PHPUnit_Framework_TestCase
}
$this->expectOutputString($out);
- PMA_display_html_radio($name, $choices, $checked_choice, false);
+ PMA_displayHtmlRadio($name, $choices, $checked_choice, false);
}
- function testDisplayHtmlRadioEscapeLabelEscapeLabel()
+ function testGetRadioFieldsEscapeLabelEscapeLabel()
{
$name = "test_display_radio";
$choices = array('value_1'=>'choice_1', 'value_&2'=>'choice&_&lt;2&gt;');
@@ -133,10 +133,10 @@ class PMA_display_html_radio_test extends PHPUnit_Framework_TestCase
}
$this->expectOutputString($out);
- PMA_display_html_radio($name, $choices, $checked_choice, true, true);
+ PMA_displayHtmlRadio($name, $choices, $checked_choice, true, true);
}
- function testDisplayHtmlRadioEscapeLabelNotEscapeLabel()
+ function testGetRadioFieldsEscapeLabelNotEscapeLabel()
{
$name = "test_display_radio";
$choices = array('value_1'=>'choice_1', 'value_&2'=>'choice&_&lt;2&gt;');
@@ -156,10 +156,10 @@ class PMA_display_html_radio_test extends PHPUnit_Framework_TestCase
}
$this->expectOutputString($out);
- PMA_display_html_radio($name, $choices, $checked_choice, true, false);
+ PMA_displayHtmlRadio($name, $choices, $checked_choice, true, false);
}
- function testDisplayHtmlRadioEscapeLabelEscapeLabelWithClass()
+ function testGetRadioFieldsEscapeLabelEscapeLabelWithClass()
{
$name = "test_display_radio";
$choices = array('value_1'=>'choice_1', 'value_&2'=>'choice&_&lt;2&gt;');
@@ -182,6 +182,6 @@ class PMA_display_html_radio_test extends PHPUnit_Framework_TestCase
}
$this->expectOutputString($out);
- PMA_display_html_radio($name, $choices, $checked_choice, true, true, $class);
+ PMA_displayHtmlRadio($name, $choices, $checked_choice, true, true, $class);
}
} \ No newline at end of file
@@ -1,7 +1,7 @@
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
- * Test for PMA_display_html_radio from common.lib.php
+ * Test for PMA_getRadioFields from common.lib.php
*
* @package PhpMyAdmin-test